=================
Protocol Module
=================
.. currentmodule:: stravalib.model

This module contains only one class. This class handles interactions
with the Strava V3 API including steps in the authentication
process.

.. automodule:: stravalib.protocol
   :members:
   :undoc-members:
   :show-inheritance:
